@@ -26,7 +26,7 @@ __all__ = ['preprocessing_training']
 
 
 def preprocessing_training_common(df, config, industry_dictionary, state_dictionary,
-                                  mx_prob_dictionary, mx_bv_dictionary, model_type):
+                                  mx_prob_dictionary, mx_bv_dictionary, model_type,imp=None):
     """Common functions used for every campaign in the processing
 
     Args:
@@ -39,6 +39,7 @@ def preprocessing_training_common(df, config, industry_dictionary, state_diction
         model_type(dict): model used ( bv, probabiltiy or multiclass)
     Returns:
         [DataFrames]: [Training and testing divided into dependent and independent variables ]
+        [imp]: iterative imputer
     """
     # Set Types
     df = devutils.set_dataframe_columntypes( df )
@@ -94,28 +95,31 @@ def preprocessing_training_common(df, config, industry_dictionary, state_diction
 
     # Use imputer
     impute_columns = config['impute_columns']
-    df_leads_clean, imp = devutils.impute_nas_and_save_imputer( df=df, columns_to_impute=impute_columns )
-    imputer_name = config['imputer_name']
-    imputer_output_path = os.path.join( '/opt/ml/processing/imputer', imputer_name )
-    logging.info( 'Saving iterative imputer to {}'.format( imputer_output_path ) )
-    pickle.dump( imp, open( imputer_output_path, 'wb' ) )
+    if (imp):
+        df=devutils.impute_nas(df=df,columns_to_impute=impute_columns,imp=imp)
+    else:
+        df, imp = devutils.impute_nas_and_save_imputer( df=df, columns_to_impute=impute_columns )
+        imputer_name = config['imputer_name']
+        imputer_output_path = os.path.join( '/opt/ml/processing/imputer', imputer_name )
+        logging.info( 'Saving iterative imputer to {}'.format( imputer_output_path ) )
+        pickle.dump( imp, open( imputer_output_path, 'wb' ) )
 
     # Logs
     cols_to_transform = config['cols_to_transform']
-    df = devutils.log_transformation( df_leads_clean, columns=cols_to_transform )
+    df = devutils.log_transformation( df, columns=cols_to_transform )
 
     # Dropping unused variables
     print( model_type )
     cols_to_drop = config['cols_to_drop'][model_type]
     df = utils.drop_columns( df=df, columns=cols_to_drop )
 
-    return df
+    return df,imp
 
 
 
 def preprocessing_training(df, industry_dictionary, state_dictionary,
                            mx_bv_dictionary, mx_prob_dictionary, config, model_type,
-                           use_one_hot_encoding):
+                           use_one_hot_encoding,imp=None):
     """[Pre-processing function to prepare the data for training the model and to make predictions]
 
     Args:
@@ -137,13 +141,14 @@ def preprocessing_training(df, industry_dictionary, state_dictionary,
     logging.info( f"NA in original dataframe:" )
     logging.info( f"{nna}" )
 
-    df_leads_clean = preprocessing_training_common( df=df_leads_clean,
+    df_leads_clean,imp = preprocessing_training_common( df=df_leads_clean,
                                                     config=config,
                                                     industry_dictionary=industry_dictionary,
                                                     mx_prob_dictionary=mx_prob_dictionary,
                                                     mx_bv_dictionary=mx_bv_dictionary,
                                                     state_dictionary=state_dictionary,
-                                                    model_type=model_type )
+                                                    model_type=model_type,
+                                                    imp=imp )
 
     df_leads_clean = utils.reduce_mem_usage_category( df=df_leads_clean )
     if(use_one_hot_encoding):
@@ -157,6 +162,6 @@ def preprocessing_training(df, industry_dictionary, state_dictionary,
     logging.info( f"NA in final dataframe:" )
     logging.info( f"{nna}" )
 
-    return df_leads_clean
+    return df_leads_clean,imp
 
 
