@@ -40,8 +40,8 @@ def set_dataframe_columntypes(df):
         df['idLead'] = df['idLead'].astype('int32')
     if 'idCampaign' in df:
         df['idCampaign'] = df['idCampaign'].astype('int8')
-    if 'bulk_status' in df:
-        df['bulk_status'] = df['bulk_status'].astype('object')
+    if 'BulkStatus' in df:
+        df['BulkStatus'] = df['BulkStatus'].astype('object')
     if 'campaign_bulk_date' in df:
         df['campaign_bulk_date'] = df['campaign_bulk_date'].astype('object')
         df['campaign_bulk_date'] = pd.to_datetime(df['campaign_bulk_date'])
